@@ -65,7 +65,7 @@ ConstantMap = {
     bytes: lambda x: plt.ByteString(x),
     int: lambda x: plt.Integer(x),
     bool: plt.Bool,
-    type(None): lambda _: plt.NoneData(),
+    type(None): lambda _: plt.Unit(),
 }
 
 
@@ -178,8 +178,13 @@ class UPLCCompiler(CompilingNodeTransformer):
                 possible_types = second_arg.typ.typs
             else:
                 possible_types = [second_arg.typ]
-            enable_double_func_mint_spend = all(
-                not isinstance(t, RecordType) or t.record.constructor != 0
+            if any(isinstance(t, UnitType) for t in possible_types):
+                _LOGGER.warning(
+                    "The redeemer is annotated to be 'None'. This value is usually encoded in PlutusData with constructor id 0 and no fields. If you want the script to double function as minting and spending script, annotate the second argument with 'NoRedeemer'."
+                )
+            enable_double_func_mint_spend = not any(
+                (isinstance(t, RecordType) and t.record.constructor != 0)
+                or isinstance(t, UnitType)
                 for t in possible_types
             )
             if not enable_double_func_mint_spend:
@@ -230,7 +235,7 @@ class UPLCCompiler(CompilingNodeTransformer):
         return plt.Lambda([STATEMONAD], plt_type(node.value))
 
     def visit_NoneType(self, _: typing.Optional[typing.Any]) -> plt.AST:
-        return plt.Lambda([STATEMONAD], plt.NoneData())
+        return plt.Lambda([STATEMONAD], plt.Unit())
 
     def visit_Assign(self, node: TypedAssign) -> plt.AST:
         assert (
